.\" @project      The CERN Tape Archive (CTA)
.\" @copyright    Copyright © 2002-2022 CERN
.\" @license      This program is free software, distributed under the terms of the GNU General Public
.\"               Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING". You can
.\"               redistribute it and/or modify it under the terms of the GPL Version 3, or (at your
.\"               option) any later version.
.\"
.\"               This program is distributed in the hope that it will be useful, but WITHOUT ANY
.\"               WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
.\"               PARTICULAR PURPOSE. See the GNU General Public License for more details.
.\"
.\"               In applying this licence, CERN does not waive the privileges and immunities
.\"               granted to it by virtue of its status as an Intergovernmental Organization or
.\"               submit itself to any jurisdiction.
.TH RMC_GET_GEOMETRY "3castor" "$Date: 2002/12/06 15:58:33 $" CASTOR "rmc Library Functions"
.SH NAME
rmc_get_geometry \- send a request to the Remote Media Changer daemon to get the robot geometry
.SH SYNOPSIS
.B #include <sys/types.h>
.br
\fB#include "rmc_api.h"\fR
.sp
.BI "int rmc_get_geometry (char *" server ,
.BI "char *" smc_ldr ,
.BI "struct robot_info *" robot_info );
.SH DESCRIPTION
.B rmc_get_geometry
asks the Remote Media Changer server running on
.I server
and connected to the picker
.I smc_ldr
to get the robot geometry.
.TP
.I server
specifies the Remote Media Changer to be contacted.
.TP
.I smc_ldr
is the picker device as defined in /dev.
.TP
.I robot_info
gives the address of the buffer allocated by the calling program to receive the
reply.
.PP
.nf
.ft CW
struct robot_info {
        char inquiry[32];
        int transport_start;
        int transport_count;
        int slot_start;
        int slot_count;
        int port_start;
        int port_count;
        int device_start;
        int device_count;
};
.ft
.fi
.SH RETURN VALUE
This routine returns 0 if the operation was successful or -1 if the operation
failed. In the latter case,
.B serrno
is set appropriately.
.SH ERRORS
.TP 1.2i
.B SECOMERR
Communication error.
.TP
.B ERMCUNREC
Unknown host or invalid loader.
.TP
.B ERMCFASTR
Unit attention.
.TP
.B ERMCOMSGR
Hardware error.
.SH SEE ALSO
.B smc(1)
.SH AUTHOR
\fBCASTOR\fP Team <castor.support@cern.ch>
