.\" @project      The CERN Tape Archive (CTA)
.\" @copyright    Copyright © 2002-2022 CERN
.\" @license      This program is free software, distributed under the terms of the GNU General Public
.\"               Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING". You can
.\"               redistribute it and/or modify it under the terms of the GPL Version 3, or (at your
.\"               option) any later version.
.\"
.\"               This program is distributed in the hope that it will be useful, but WITHOUT ANY
.\"               WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
.\"               PARTICULAR PURPOSE. See the GNU General Public License for more details.
.\"
.\"               In applying this licence, CERN does not waive the privileges and immunities
.\"               granted to it by virtue of its status as an Intergovernmental Organization or
.\"               submit itself to any jurisdiction.
.TH RMC_MOUNT "3castor" "$Date: 2002/12/06 15:58:33 $" CASTOR "rmc Library Functions"
.SH NAME
rmc_mount \- send a request to the Remote Media Changer daemon to have a volume mounted
.SH SYNOPSIS
.B #include <sys/types.h>
.br
\fB#include "rmc_api.h"\fR
.sp
.BI "int rmc_mount (char *" server ,
.BI "char *" smc_ldr ,
.BI "char *" vid ,
.BI "int " side ,
.BI "int " drvord );
.SH DESCRIPTION
.B rmc_mount
asks the Remote Media Changer server running on
.I server
and connected to the picker
.I smc_ldr
to mount the volume
.I vid
on the drive specified by
.IR drvord .
.TP
.I server
specifies the Remote Media Changer to be contacted.
.TP
.I smc_ldr
is the picker device as defined in /dev.
.TP
.I vid
is the volume visual identifier.
It must be at most six characters long.
.TP
.I side
is an integer specifying the side number.
This field is only used if the specified device offers several sides,
for example a DVD.
.TP
.I drvord
specifies the drive ordinal in the robot.
.SH RETURN VALUE
This routine returns 0 if the operation was successful or -1 if the operation
failed. In the latter case,
.B serrno
is set appropriately.
.SH ERRORS
.TP 1.2i
.B SECOMERR
Communication error.
.TP
.B ERMCUNREC
Unknown host or invalid loader or vid too long or invalid drive ordinal.
.TP
.B ERMCFASTR
Unit attention.
.TP
.B ERMCOMSGR
Hardware error or Medium Removal Prevented.
.SH SEE ALSO
.BR rmc_get_geometry(3) ,
.B smc(1)
.SH AUTHOR
\fBCASTOR\fP Team <castor.support@cern.ch>
